@@ -232,16 +232,16 @@ class IssueDevelopment(observer.Observer):
         if self.write_voting_position:
             writer.writerow(
                 [
-                    "round",
-                    "preference nbs",
-                    "preference nbs var",
+                    "Round",
+                    "Preference MDS",
+                    "Preference MDS variance",
                     "",
-                    "voting nbs",
-                    "voting nbs var",
+                    "Voting MDS",
+                    "Voting MDS variance",
                 ]
             )
         else:
-            writer.writerow(["round", "preference nbs", "preference nbs var"])
+            writer.writerow(["Round", "Preference MDS", "Preference MDS variance"])
 
         # remove the nbs from each collection so it doesn't show up in the table.
         preference_nbs = self.preference_history[issue]["nbs"]
@@ -283,7 +283,7 @@ class IssueDevelopment(observer.Observer):
         # issue development summary
         writer.writerow([])
         writer.writerow(
-            ["First and last round comparison of NBS and all actors"]
+            ["First and last round comparison of MDS and all actors"]
         )
         writer.writerow(
             [
@@ -293,15 +293,15 @@ class IssueDevelopment(observer.Observer):
                 "First round",
                 "Final round",
                 "Position shift",
-                "Distance NBS start",
-                "Distance NBS end",
+                "Distance MDS start",
+                "Distance MDS end",
             ]
         )
 
         nbs_start = self._de_normalize_value(preference_nbs[0])
         nbs_end = self._de_normalize_value(preference_nbs[-1])
 
-        writer.writerow(["NBS", "-", "-", nbs_start, nbs_end, "-"])
+        writer.writerow(["MDS", "-", "-", nbs_start, nbs_end, "-"])
 
         # to compare different issues and variances of the model, keep the output sorted
         od = OrderedDict(sorted(self.preference_history[issue].items()))
@@ -333,16 +333,16 @@ class IssueDevelopment(observer.Observer):
 
         # second table
         writer.writerow([])
-        writer.writerow(["Preference development NBS and all actors"])
+        writer.writerow(["Preference development MDS and all actors"])
         writer.writerow(["actor", "salience", "power"] + heading)
 
         plt.clf()
 
         nbs_values = self._de_normalize_list_value(preference_nbs)
 
-        writer.writerow(["nbs", "-", "-"] + nbs_values)
+        writer.writerow(["MDS", "-", "-"] + nbs_values)
 
-        plt.plot(nbs_values, label="nbs")
+        plt.plot(nbs_values, linestyle="--",  label="MDS")
 
         for actor_id, value in od.items():
             actor_issue = self.model_ref.actor_issues[self.issue_obj][actor_id]
@@ -366,11 +366,11 @@ class IssueDevelopment(observer.Observer):
 
         if self.write_voting_position:
             writer.writerow([])
-            writer.writerow(["Voting development NBS and all actors"])
+            writer.writerow(["Voting development MDS and all actors"])
             writer.writerow(["Actor", "Salience", "Power"] + heading)
 
             writer.writerow(
-                ["NBS", "-", "-"] + self._de_normalize_list_value(voting_nbs)
+                ["MDS", "-", "-"] + self._de_normalize_list_value(voting_nbs)
             )
 
             od = OrderedDict(sorted(self.voting_history[issue].items()))
@@ -438,13 +438,13 @@ class IssueDevelopment(observer.Observer):
                     writer.writerow(
                         [
                             "round",
-                            "avg nbs",
+                            "avg MDS",
                             "variance",
                             "",
-                            "avg voting nbs",
+                            "avg voting MDS",
                             "variance",
                             "",
-                            "avg nbs var",
+                            "avg MDS var",
                             "variance",
                             "",
                             "avg voting variance",
@@ -455,10 +455,10 @@ class IssueDevelopment(observer.Observer):
                     writer.writerow(
                         [
                             "round",
-                            "avg nbs",
+                            "avg MDS",
                             "variance",
                             "",
-                            "avg voting nbs",
+                            "avg voting MDS",
                             "variance",
                         ]
                     )
@@ -477,7 +477,7 @@ class IssueDevelopment(observer.Observer):
 
                 _ = self._de_normalize_value
 
-                # NBS related data.
+                # MDS related data.
                 plt.clf()
 
                 p_line = []
@@ -534,11 +534,11 @@ class IssueDevelopment(observer.Observer):
                         nbs_start = _(p[0])
                     nbs_end = _(p[0])
 
-                plt.plot(p_line, label="nbs")
+                plt.plot(p_line, linestyle="--", label="MDS")
 
                 writer.writerow([])
                 writer.writerow(
-                    ["[Preference] First and last round comparison of NBS and all actors"]
+                    ["[Preference] First and last round comparison of MDS and all actors"]
                 )
                 writer.writerow(
                     [
@@ -548,12 +548,12 @@ class IssueDevelopment(observer.Observer):
                         "First round",
                         "Final round",
                         "Position shift",
-                        "Distance NBS start",
-                        "Distance NBS end",
+                        "Distance MDS start",
+                        "Distance MDS end",
                     ]
                 )
 
-                writer.writerow(["NBS", "-", "-", nbs_start, nbs_end, "-"])
+                writer.writerow(["MDS", "-", "-", nbs_start, nbs_end, "-"])
 
                 for actor, value in sorted(self.preference_history_sum[issue].items()):
 
@@ -584,7 +584,7 @@ class IssueDevelopment(observer.Observer):
 
                 writer.writerow([])
                 writer.writerow(
-                    ["[Voting] First and last round comparison of NBS and all actors"]
+                    ["[Voting] First and last round comparison of MDS and all actors"]
                 )
                 writer.writerow(
                     [
@@ -594,12 +594,12 @@ class IssueDevelopment(observer.Observer):
                         "First round",
                         "Final round",
                         "Position shift",
-                        "Distance NBS start",
-                        "Distance NBS end",
+                        "Distance MDS start",
+                        "Distance MDS end",
                     ]
                 )
 
-                writer.writerow(["NBS", "-", "-", nbs_voting_start, nbs_voting_end, "-"])
+                writer.writerow(["MDS", "-", "-", nbs_voting_start, nbs_voting_end, "-"])
 
                 for actor, value in sorted(self.voting_history_sum[issue].items()):
 
@@ -629,45 +629,59 @@ class IssueDevelopment(observer.Observer):
                     )
 
                 writer.writerow([])
-                writer.writerow(["AVG Preference development NBS and all actors"])
+                writer.writerow(["AVG Preference development MDS and all actors"])
                 writer.writerow(["actor", "salience", "power"] + heading)
 
-                var_rows = []
-
-                for actor, value in sorted(self.preference_history_sum[issue].items()):
-
-                    actor_issue = self.model_ref.actor_issues[issue][actor]
-
-                    row = [actor, actor_issue.salience, actor_issue.power]
-                    var_row = [actor, actor_issue.salience, actor_issue.power]
-
-                    avg_row = []
-                    for iteration, values in value.items():
-                        avg, var = calculations.average_and_variance(values)
-                        avg_row.append(_(avg))
-                        var_row.append(math.sqrt(var))
-
-                    plt.plot(avg_row, label=actor.name)
-
-                    writer.writerow(row + avg_row)
-                    var_rows.append(var_row)
+                self._write_history_sum(writer, heading, issue, self.preference_history_sum, "preference")
 
                 writer.writerow([])
-                writer.writerow(["Standard deviation"])
+                writer.writerow(["AVG voting development MDS and all actors"])
                 writer.writerow(["actor", "salience", "power"] + heading)
 
-                for row in var_rows:
-                    writer.writerow(row)
+                if self.write_voting_position:
+                    self._write_history_sum(writer, heading, issue, self.voting_history_sum, "voting")
 
-                lgd = plt.legend(loc="upper left", bbox_to_anchor=(1, 1))
-                plt.title(self.issue_obj)
-                plt.savefig(
-                    "{0}/issues/{2}/charts/{1}.png".format(
-                        self.output_directory, self.issue_obj.issue_id, "summary"
-                    ),
-                    bbox_extra_artists=(lgd,),
-                    bbox_inches="tight",
-                )
+
+    def _write_history_sum(self, writer, heading, issue, data, label):
+
+        plt.clf()
+
+        var_rows = []
+
+        for actor, value in sorted(data[issue].items()):
+
+            actor_issue = self.model_ref.actor_issues[issue][actor]
+
+            row = [actor, actor_issue.salience, actor_issue.power]
+            var_row = [actor, actor_issue.salience, actor_issue.power]
+
+            avg_row = []
+            for iteration, values in value.items():
+                avg, var = calculations.average_and_variance(values)
+                avg_row.append(self._de_normalize_value(avg))
+                var_row.append(math.sqrt(var))
+
+            plt.plot(avg_row, label=actor.name)
+
+            writer.writerow(row + avg_row)
+            var_rows.append(var_row)
+
+        writer.writerow([])
+        writer.writerow(["Standard deviation {0}".format(label)])
+        writer.writerow(["actor", "salience", "power"] + heading)
+
+        for row in var_rows:
+            writer.writerow(row)
+
+        lgd = plt.legend(loc="upper left", bbox_to_anchor=(1, 1))
+        plt.title(self.issue_obj)
+        plt.savefig(
+            "{0}/issues/{2}/charts/{1}.{3}.png".format(
+                self.output_directory, self.issue_obj.issue_id, "summary", label
+            ),
+            bbox_extra_artists=(lgd,),
+            bbox_inches="tight",
+        )
 
     @property
     def _get_salt(self):
